@@ -55,7 +55,7 @@ import qualified Data.ByteString.Unsafe            as B
 import           Data.Text                         (Text)
 import qualified Data.Text                         as T
 import qualified Data.Text.Array                   as A
-import           Data.Text.Internal                (textP)
+import           Data.Text.Internal                (text)
 import qualified Data.Text.Internal.Encoding.Utf16 as U16
 import qualified Data.Text.Internal.Encoding.Utf32 as U32
 import qualified Data.Text.Internal.Encoding.Utf8  as U8
@@ -92,7 +92,7 @@ toBS (S3 a b c) = B.pack [a, b, c]
 getText :: Int -> A.MArray s -> ST s Text
 getText j marr = do
     arr <- A.unsafeFreeze marr
-    return $! textP arr 0 j
+    return $! text arr 0 j
 {-# INLINE getText #-}
 
 #include "text_cbits.h"
@@ -105,7 +105,7 @@ foreign import ccall unsafe "_hs_streaming_commons_decode_utf8_state" c_decode_u
 newtype CodePoint = CodePoint Word32 deriving (Eq, Show, Num, Storable)
 newtype DecoderState = DecoderState Word32 deriving (Eq, Show, Num, Storable)
 
--- | /O(n)/ Convert a lazy 'ByteString' into a 'Stream Char', using
+-- | /O(n)/ Convert a 'ByteString' into a 'Stream Char', using
 -- UTF-8 encoding.
 decodeUtf8 :: B.ByteString -> DecodeResult
 decodeUtf8 = decodeChunk B.empty 0 0
@@ -138,7 +138,7 @@ decodeUtf8 = decodeChunk B.empty 0 0
               n <- peek destOffPtr
               chunkText <- unsafeSTToIO $ do
                   arr <- A.unsafeFreeze dest
-                  return $! textP arr 0 (fromIntegral n)
+                  return $! text arr 0 (fromIntegral n)
               lastPtr <- peek curPtrPtr
               let left = lastPtr `minusPtr` curPtr
                   -- The logic here is: if any text was generated, then the
@@ -159,7 +159,7 @@ decodeUtf8 = decodeChunk B.empty 0 0
                          $! decodeChunkCheck unused codepoint state
         in loop (ptr `plusPtr` off)
 
--- | /O(n)/ Convert a lazy 'ByteString' into a 'Stream Char', using
+-- | /O(n)/ Convert a 'ByteString' into a 'Stream Char', using
 -- UTF-8 encoding.
 decodeUtf8Pure :: B.ByteString -> DecodeResult
 decodeUtf8Pure =
